@@ -1,14 +1,14 @@
 from multiprocessing import Pipe, Process
 from multiprocessing.connection import Connection
+import multiprocessing as mp
 from typing import Any, Callable, List, Tuple
 import time
-
-from ez_task.manager import TaskManager
 from .types.health_check import HealthCheck
 from .gatherer import Gatherer
+from . import config
 
 class Task():
-    def __init__(self, target: Callable, daemon=True, manager: TaskManager = None, use_gatherer=True) -> None:
+    def __init__(self, target: Callable, daemon=True, manager = None, use_gatherer=True, start_method=None) -> None:
         """
         Creates an instance of the Task object.
 
@@ -18,21 +18,28 @@ class Task():
         ----------
         target : Callable
             Any top level python function or callable class attribute
-
+        daemon: bool (default True)
+            Sets subordinate multiprocessing.Process daemon value
+        use_gatherer: bool (default True)
+            Controls whether Task utilizes threaded ez_task.gatherer.Gatherer
+        start_method: string (default None)
+            Sets the start method ('fork', 'spawn', 'forkserver') for subordinate
+            multiprocessing.Process 
         Returns
         -------
         Task
             An instance of ez_task.task.Task 
 
         """
-        self.manager: TaskManager = manager 
+        self.manager = manager 
         connections: Tuple[Connection, Connection] = Pipe()
         self._internal_connection, self._external_connection = connections
         self.gatherer: Gatherer = None
         if (use_gatherer):
             self.gatherer = Gatherer(self._external_connection)
         self._target = target
-        self.process: Process = Process(target=Task._call_function, args=(self._internal_connection, self._target), daemon=daemon)
+        ctx = mp.get_context(method=start_method)
+        self.process: Process = ctx.Process(target=Task._call_function, args=(self._internal_connection, self._target), daemon=daemon)
         self.process.start()
         self.is_initialized: bool = False
         pass
@@ -133,13 +140,11 @@ class Task():
             time.sleep(0.1)
         pass
 
-
     def get_result(self) -> Any:
         """
         Returns the result of a previous invocation of Task.run
-
         Blocks until a result of Task.run is available.
-        
+
         Parameters
         ----------
         None
@@ -159,10 +164,22 @@ class Task():
         return result
 
     def get_all_results(self) -> List[Any]:
-        return self.gatherer.get_all_results()
+        """
+        
+        """
+        if self.gatherer:
+            return self.gatherer.get_all_results()
+
+        result_list = []
+        while self._external_connection.poll():
+            result = self._external_connection.recv()
+            result_list.append(result)
+        return result_list
 
     @staticmethod
     def _call_function(conn, function):
+        if config.verbose:
+            print(f'EZ-TASK started {mp.current_process()} calling {function}')
         while True:
             res = conn.recv()
             if (isinstance(res, tuple)):
